# History

## 0.2.0 (2021-01-29)

- Alpha release

### 0.2.1 (2021-01-29)

- Package metadata fixes (author, email, url)
- Miscellaneous documentation improvements

## 0.1.0 (2020-09-11)

- Test release

### 0.1.1 (2021-01-29)

- Test release

## 0.0.0 (2020-09-11)

- pyribs begins
